@@ -7,7 +7,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: blowfish.c,v 1.5 2000/10/12 21:06:31 nmav Exp $ */
+/* $Id: blowfish.c,v 1.6 2000/11/08 23:25:36 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -156,7 +156,7 @@ void _mcrypt_decrypt(blf_ctx * c, word32 * x)
 }
 
 
-static short initialize_blowfish(blf_ctx * c, char key[], short keybytes)
+static short initialize_blowfish(blf_ctx * c, unsigned char key[], short keybytes)
 {
 	short i, j;
 	word32 data, datarl[2];
