@@ -13,7 +13,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: rc2.c,v 1.3 2000/09/16 02:01:38 nmav Exp $ */
+/* $Id: rc2.c,v 1.5 2000/10/12 21:06:31 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -42,6 +42,7 @@
 * zero is accepted as an alias for 1024.                               *
 \**********************************************************************/
 
+WIN32DLL_DEFINE
 void _mcrypt_set_key(word16 * xkey, const word8 * key,
 			     unsigned int len)
 {
@@ -115,15 +116,16 @@ void _mcrypt_set_key(word16 * xkey, const word8 * key,
 * Encrypt an 8-byte block of plaintext using the given key.            *
 \**********************************************************************/
 
+WIN32DLL_DEFINE
 void _mcrypt_encrypt(const word16 * xkey, word16 * plain)
 {
 	word16 x3, x2, x1, x0, i;
 
 #ifdef WORDS_BIGENDIAN
-	x3 = byteswap_16(plain[3]);
-	x2 = byteswap_16(plain[2]);
-	x1 = byteswap_16(plain[1]);
-	x0 = byteswap_16(plain[0]);
+	x3 = byteswap16(plain[3]);
+	x2 = byteswap16(plain[2]);
+	x1 = byteswap16(plain[1]);
+	x0 = byteswap16(plain[0]);
 #else
 	x3 = plain[3];
 	x2 = plain[2];
@@ -153,10 +155,10 @@ void _mcrypt_encrypt(const word16 * xkey, word16 * plain)
 	}
 
 #ifdef WORDS_BIGENDIAN
-	plain[0] = byteswap_16(x0);
-	plain[1] = byteswap_16(x1);
-	plain[2] = byteswap_16(x2);
-	plain[3] = byteswap_16(x3);
+	plain[0] = byteswap16(x0);
+	plain[1] = byteswap16(x1);
+	plain[2] = byteswap16(x2);
+	plain[3] = byteswap16(x3);
 #else
 	plain[0] = (x0);
 	plain[1] = (x1);
@@ -171,6 +173,7 @@ void _mcrypt_encrypt(const word16 * xkey, word16 * plain)
 * Decrypt an 8-byte block of ciphertext using the given key.           *
 \**********************************************************************/
 
+WIN32DLL_DEFINE
 void _mcrypt_decrypt(const word16 * xkey, word16 * plain)
 {
 	word16 x3, x2, x1, x0, i;
@@ -181,10 +184,10 @@ void _mcrypt_decrypt(const word16 * xkey, word16 * plain)
 	x1 = plain[1];
 	x0 = plain[0];
 #else
-	x3 = byteswap_16(plain[3]);
-	x2 = byteswap_16(plain[2]);
-	x1 = byteswap_16(plain[1]);
-	x0 = byteswap_16(plain[0]);
+	x3 = byteswap16(plain[3]);
+	x2 = byteswap16(plain[2]);
+	x1 = byteswap16(plain[1]);
+	x0 = byteswap16(plain[0]);
 #endif
 
 
@@ -211,10 +214,10 @@ void _mcrypt_decrypt(const word16 * xkey, word16 * plain)
 	} while (i--);
 
 #ifdef WORDS_BIGENDIAN
-	plain[0] = byteswap_16(x0);
-	plain[1] = byteswap_16(x1);
-	plain[2] = byteswap_16(x2);
-	plain[3] = byteswap_16(x3);
+	plain[0] = byteswap16(x0);
+	plain[1] = byteswap16(x1);
+	plain[2] = byteswap16(x2);
+	plain[3] = byteswap16(x3);
 #else
 	plain[0] = x0;
 	plain[1] = x1;
@@ -223,18 +226,25 @@ void _mcrypt_decrypt(const word16 * xkey, word16 * plain)
 #endif
 }
 
+WIN32DLL_DEFINE
 int _mcrypt_get_size () {return 64*sizeof(word16);}
+WIN32DLL_DEFINE
 int _mcrypt_get_block_size() { return 8; }
+WIN32DLL_DEFINE
 int _is_block_algorithm() { return 1; }
+WIN32DLL_DEFINE
 int _mcrypt_get_key_size() { return 128; }
+WIN32DLL_DEFINE
 int* _mcrypt_get_supported_key_sizes(int *len) {
 	*len=0;
         return NULL;
 }
+WIN32DLL_DEFINE
 char * _mcrypt_get_algorithms_name() { char*x; x=malloc(10); strcpy(x, "RC2"); return x;}
 
 #define CIPHER "becbe4c8e6237a14"
 
+WIN32DLL_DEFINE
 int _mcrypt_self_test() {
 	char *keyword;
 	unsigned char *plaintext;
@@ -277,6 +287,7 @@ int _mcrypt_self_test() {
 	return 0;
 }
 
+WIN32DLL_DEFINE
 word32 _mcrypt_algorithm_version() {
 	return 19991129;
 }
